@@ -35,7 +35,7 @@ FakeNetworkReply::FakeNetworkReply(const FakeNetworkAccessManager::Scenario &sce
     } else {
         setHeader(QNetworkRequest::ContentTypeHeader, QStringLiteral("text/plain"));
     }
-    for (const auto header : qAsConst(scenario.responseHeaders)) {
+    for (const auto &header : qAsConst(scenario.responseHeaders)) {
         setRawHeader(header.first, header.second);
     }
 
