@@ -29,6 +29,8 @@
 
 #include <QFlags>
 
+class QNetworkRequest;
+
 namespace KGAPI2
 {
 
@@ -45,6 +47,13 @@ namespace CalendarService
     };
     using EventSerializeFlags = QFlags<EventSerializeFlag>;
 
+    /**
+     * @brief Preparse a QNetworkRequest for given URL
+     *
+     * @param url
+     */
+    KGAPICALENDAR_EXPORT QNetworkRequest prepareRequest(const QUrl &url);
+
     /**
      * @brief Parses calendar JSON data into Calendar object
      *
