@@ -166,6 +166,22 @@ void EventFetchJob::start()
 
 ObjectsList EventFetchJob::handleReplyWithItems(const QNetworkReply *reply, const QByteArray& rawData)
 {
+#if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
+    if (reply->error() == QNetworkReply::ContentGoneError
+#else
+    if (reply->networkError() == QNetworkReply::ContentGoneError
+#endif
+        || reply->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt() == Gone) {
+        // Full sync required by server, redo request with no updatedMin
+        d->updatedTimestamp = 0;
+        start();
+        // Errors are not cleared on success
+        // Do it here or else the job will fail
+        setError(KGAPI2::NoError);
+        setErrorString(QString());
+        return ObjectsList();
+    }
+
     FeedData feedData;
     feedData.requestUrl = reply->url();
     ObjectsList items;
