@@ -17,7 +17,7 @@
  * GNU Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef LIBKGAPI2_EVENTFETCHJOB_H
@@ -26,6 +26,8 @@
 #include "fetchjob.h"
 #include "kgapicalendar_export.h"
 
+#include <QScopedPointer>
+
 namespace KGAPI2 {
 
 /**
@@ -88,7 +90,7 @@ class KGAPICALENDAR_EXPORT EventFetchJob : public KGAPI2::FetchJob
     /**
      * @brief Timestamp of the oldest event that will be fetched
      *
-     * Only events ocurring after or precisely at the time indicated by this
+     * Only events occurring after or precisely at the time indicated by this
      * property will be fetched.
      *
      * By default the timestamp is 0 and no limit is applied.
@@ -230,7 +232,7 @@ class KGAPICALENDAR_EXPORT EventFetchJob : public KGAPI2::FetchJob
 
   private:
     class Private;
-    Private * const d;
+    QScopedPointer<Private> const d;
     friend class Private;
 
 };
