@@ -15,7 +15,7 @@
     GNU Lesser General Public License for more details.
 
     You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    License along with this library.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #include "account.h"
@@ -201,3 +201,8 @@ QUrl Account::mailScopeUrl()
 {
     return QUrl(QStringLiteral("https://mail.google.com/"));
 }
+
+QUrl Account::driveScopeUrl()
+{
+    return QUrl(QStringLiteral("https://www.googleapis.com/auth/drive"));
+}
