@@ -49,8 +49,8 @@ AccountInfoFetchJob::~AccountInfoFetchJob()
 
 void AccountInfoFetchJob::start()
 {
-    QNetworkRequest request(QUrl(QStringLiteral("https://www.googleapis.com/oauth2/v1/userinfo")));
-    request.setRawHeader("Authorization", "Bearer " + account()->accessToken().toLatin1());
+    const QUrl url = QUrl(QStringLiteral("https://www.googleapis.com/oauth2/v1/userinfo"));
+    QNetworkRequest request(url);
 
     QStringList headers;
     const auto rawHeaderList = request.rawHeaderList();
