@@ -561,7 +561,7 @@ AboutPtr About::fromJSON(const QByteArray &jsonData)
     }
     const QVariantMap map = document.toVariant().toMap();
 
-    if (!map.contains(QStringLiteral("kind")) ||
+    if (!map.contains(QLatin1String("kind")) ||
         map[QStringLiteral("kind")].toString() != QLatin1String("drive#about")) {
 
         return AboutPtr();
