@@ -15,7 +15,7 @@
     GNU Lesser General Public License for more details.
 
     You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    License along with this library.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #ifndef LIBKGAPI2_DRIVE_CHILDREFERENCE_H
@@ -51,6 +51,8 @@ class KGAPIDRIVE_EXPORT ChildReference: public KGAPI2::Object
     explicit ChildReference(const QString &id);
     explicit ChildReference(const ChildReference &other);
     ~ChildReference() override;
+    bool operator==(const ChildReference &other) const;
+    bool operator!=(const ChildReference &other) const { return !operator==(other); }
 
     /**
      * @brief Returns the id of the child.
