@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2014  Daniel Vrátil <dvratil@redhat.com>
+ * Copyright (C) 2019  David Barchiesi <david@barchie.si>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -15,7 +16,7 @@
  * GNU Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef KGAPI2_DRIVE_FILESEARCHQUERY_H
@@ -23,6 +24,8 @@
 
 #include "kgapidrive_export.h"
 
+#include "searchquery.h"
+
 #include <QVariant>
 #include <QSharedDataPointer>
 
@@ -40,7 +43,7 @@ namespace Drive
  *
  * @since 2.3
  */
-class KGAPIDRIVE_EXPORT FileSearchQuery
+class KGAPIDRIVE_EXPORT FileSearchQuery : public SearchQuery
 {
 public:
     enum Field {
@@ -59,38 +62,14 @@ public:
         /*Properties            FIXME: Not supported atm */
     };
 
-    enum CompareOperator {
-        Contains,
-        Equals,
-        NotEquals,
-        Less,
-        LessOrEqual,
-        Greater,
-        GreaterOrEqual,
-        In,
-        Has
-    };
-
-    enum LogicOperator {
-        And,
-        Or
-    };
-
-    explicit FileSearchQuery(LogicOperator op = And);
-    FileSearchQuery(const FileSearchQuery &other);
-    FileSearchQuery &operator=(const FileSearchQuery &other);
-    ~FileSearchQuery();
+    using SearchQuery::SearchQuery;
 
+    using SearchQuery::addQuery;
     void addQuery(Field field, CompareOperator op, const QVariant &value);
-    void addQuery(const FileSearchQuery &query);
 
-    bool isEmpty() const;
-
-    QString serialize() const;
-
-  private:
-    class Private;
-    QSharedDataPointer<Private> d;
+private:
+    QString fieldToString(Field field);
+    QString valueToString(FileSearchQuery::Field field, const QVariant &var);
 };
 }
 }
