@@ -33,12 +33,17 @@
 using namespace KGAPI2;
 using namespace KGAPI2::Drive;
 
+namespace {
+    static constexpr bool useDomainAdminAccessDefault = false;
+}
+
 class Q_DECL_HIDDEN PermissionDeleteJob::Private
 {
   public:
     QString fileId;
     QStringList permissionsIds;
     bool supportsAllDrives;
+    bool useDomainAdminAccess;
 };
 
 PermissionDeleteJob::PermissionDeleteJob(const QString &fileId,
@@ -49,6 +54,7 @@ PermissionDeleteJob::PermissionDeleteJob(const QString &fileId,
     d(new Private)
 {
     d->supportsAllDrives = true;
+    d->useDomainAdminAccess = useDomainAdminAccessDefault;
     d->fileId = fileId;
     d->permissionsIds << permission->id();
 }
@@ -61,6 +67,7 @@ PermissionDeleteJob::PermissionDeleteJob(const QString &fileId,
     d(new Private)
 {
     d->supportsAllDrives = true;
+    d->useDomainAdminAccess = useDomainAdminAccessDefault;
     d->fileId = fileId;
     d->permissionsIds << permissionId;
 }
@@ -73,6 +80,7 @@ PermissionDeleteJob::PermissionDeleteJob(const QString &fileId,
     d(new Private)
 {
     d->supportsAllDrives = true;
+    d->useDomainAdminAccess = useDomainAdminAccessDefault;
     d->fileId = fileId;
     for (const PermissionPtr & permission : qAsConst(permissions)) {
         d->permissionsIds << permission->id();
@@ -87,14 +95,12 @@ PermissionDeleteJob::PermissionDeleteJob(const QString &fileId,
     d(new Private)
 {
     d->supportsAllDrives = true;
+    d->useDomainAdminAccess = useDomainAdminAccessDefault;
     d->fileId = fileId;
     d->permissionsIds << permissionsIds;
 }
 
-PermissionDeleteJob::~PermissionDeleteJob()
-{
-    delete d;
-}
+PermissionDeleteJob::~PermissionDeleteJob() = default;
 
 bool PermissionDeleteJob::supportsAllDrives() const
 {
@@ -106,6 +112,16 @@ void PermissionDeleteJob::setSupportsAllDrives(bool supportsAllDrives)
     d->supportsAllDrives = supportsAllDrives;
 }
 
+bool PermissionDeleteJob::useDomainAdminAccess() const
+{
+    return d->useDomainAdminAccess;
+}
+
+void PermissionDeleteJob::setUseDomainAdminAccess(bool useDomainAdminAccess)
+{
+    d->useDomainAdminAccess = useDomainAdminAccess;
+}
+
 void PermissionDeleteJob::start()
 {
     if (d->permissionsIds.isEmpty()) {
@@ -115,9 +131,12 @@ void PermissionDeleteJob::start()
 
     const QString permissionId = d->permissionsIds.takeFirst();
     QUrl url = DriveService::deletePermissionUrl(d->fileId, permissionId);
-    QUrlQuery withDriveSupportQuery(url);
-    withDriveSupportQuery.addQueryItem(QStringLiteral("supportsAllDrives"), Utils::bool2Str(d->supportsAllDrives));
-    url.setQuery(withDriveSupportQuery);
+    QUrlQuery query(url);
+    query.addQueryItem(QStringLiteral("supportsAllDrives"), Utils::bool2Str(d->supportsAllDrives));
+    if (d->useDomainAdminAccess != useDomainAdminAccessDefault) {
+        query.addQueryItem(QStringLiteral("useDomainAdminAccess"), Utils::bool2Str(d->useDomainAdminAccess));
+    }
+    url.setQuery(query);
     QNetworkRequest request(url);
 
     enqueueRequest(request);
