@@ -97,7 +97,7 @@ QString User::permissionId() const
 
 UserPtr User::fromJSON(const QVariantMap &map)
 {
-    if (!map.contains(QStringLiteral("kind")) ||
+    if (!map.contains(QLatin1String("kind")) ||
         map[QStringLiteral("kind")].toString() != QLatin1String("drive#user"))
     {
         return UserPtr();
