@@ -68,9 +68,7 @@ TaskFetchJob::Private::Private(TaskFetchJob* parent):
 
 QNetworkRequest TaskFetchJob::Private::createRequest(const QUrl& url)
 {
-    QNetworkRequest request;
-    request.setRawHeader("Authorization", "Bearer " + q->account()->accessToken().toLatin1());
-    request.setUrl(url);
+    QNetworkRequest request(url);
 
     QStringList headers;
     const auto rawHeaderList = request.rawHeaderList();
